(setq gnutls-algorithm-priority "NORMAL:-VERS-TLS1.3")

;; Manually installed modes
(add-to-list 'load-path "~/.emacs.d/plugins/")

;; Scheme BBS
(load "sbbs")

;; Package
(require 'package)
(setq package-archives '(("gnu" . "http://mirrors.163.com/elpa/gnu/")
                         ("melpa" . "https://melpa.org/packages/")))
(package-initialize)

;; use-package
(unless (package-installed-p 'use-package)
  (package-refresh-contents)
  (package-install 'use-package))

;; auto-package-update automatically updates and removes old packages
(use-package auto-package-update
  :ensure t
  :config
  (setq auto-package-update-delete-old-versions t)
  (setq auto-package-update-hide-results t)
  (auto-package-update-maybe))

;; better incremental search with minibuffer
(use-package swiper
  :ensure t
  :bind ("C-s" . 'swiper))

(use-package almost-mono-themes
  :ensure t
  :init
  (load-theme 'almost-mono-black t))

(use-package haskell-mode
  :ensure t
  :init
  (add-hook 'haskell-mode-hook 'interactive-haskell-mode))

(use-package go-mode
  :ensure t)

(use-package elpher
  :ensure t)

(use-package dashboard
  :ensure t
  :config
  (setq dashboard-banner-logo-title "")
  (setq dashboard-startup-banner 'logo) ; add own image?
  (setq dashboard-center-content t)
  (setq dashboard-set-footer nil)
  (dashboard-setup-startup-hook))

(use-package slime
  :ensure t
  :config
  (setq inferior-lisp-program "sbcl"))

(use-package expand-region
  :ensure t
  :config
  (global-set-key (kbd "C-=") 'er/expand-region)
  (pending-delete-mode t)) ; if you start typing while a word is selected, overwrite it

;; jump to definitions and files with M-.
(use-package dumb-jump
  :ensure t
  :config
  (add-hook 'xref-backend-functions #'dumb-jump-xref-activate))

;; avy - jump around files more easily
(use-package avy
  :ensure t
  :bind ("M-s" . avy-goto-char))

;; self explanatory
(use-package magit
  :ensure t)
